@@ -5,12 +5,6 @@ use std::fmt::Debug;
 
 pub struct Stdout;
 
-const DEFINITION: &'static str ="
-name = 'Stdout'
-[[input]]
-name = 'stdout'
-type = 'String'";
-
 impl Implementation for Stdout {
     fn number_of_inputs(&self) -> usize {
         1
@@ -21,10 +15,6 @@ impl Implementation for Stdout {
         None
     }
 
-    fn define(&self) -> &'static str {
-        DEFINITION
-    }
-
     fn name(&self) -> &'static str {
         "Stdout"
     }
